==> haskell-snap-core-1.0.5.1-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-core
version:              1.0.5.1
visibility:           public
id:                   snap-core-1.0.5.1-ArG2J5lYSwN6wtNgIbaWij
key:                  snap-core-1.0.5.1-ArG2J5lYSwN6wtNgIbaWij
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  e645201b4374db358ece78e1233be2e7
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing
    Snap.Internal.Util.FileServe Snap.Test Snap.Types.Headers
    Snap.Util.CORS Snap.Util.FileServe Snap.Util.FileUploads
    Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-core
hs-libraries:         HSsnap-core-1.0.5.1-ArG2J5lYSwN6wtNgIbaWij
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
    containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    io-streams-1.5.2.2-GOctHVyl5zA2PM884JGDoB
    lifted-base-0.2.3.12-DQLsZto8uK0Aez8LuH3ZRC
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2 mtl-2.2.2
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    network-uri-2.6.4.2-BC3te0GfpncIdQCU8I2AdS
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    readable-0.3.1-ELy7rHtD1IYJJNZUAgGrUz
    regex-posix-0.96.0.1-1Q9XmC5TCrJFDwyeT6H8gP text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unix-compat-0.7.3-GMbRcTa3W8S37RJEukw37Q
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.5.1-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-core
version:              1.0.5.1
visibility:           public
id:                   snap-core-1.0.5.1-49Grs68MTiz1QCg5eOx1PH
key:                  snap-core-1.0.5.1-49Grs68MTiz1QCg5eOx1PH
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  fdb3ac627c44b17be6e844da9bdab2d6
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing
    Snap.Internal.Util.FileServe Snap.Test Snap.Types.Headers
    Snap.Util.CORS Snap.Util.FileServe Snap.Util.FileUploads
    Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-core
hs-libraries:         HSsnap-core-1.0.5.1-49Grs68MTiz1QCg5eOx1PH
depends:
    HUnit-1.6.2.0-BbdSRE1ivgr5FoFXtFn37H
    attoparsec-0.14.4-5wZOVAk6w2AKDrkEEe6wrE base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-EnSgvsXdRX78Hz3HwummHY
    containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    io-streams-1.5.2.2-27mevNN08NvBjfoThwSYvA
    lifted-base-0.2.3.12-2Y4Pbasykn4KSjYEEBBpfz
    monad-control-1.0.3.1-BUkxO6HLLlgCLFSdrHwBde mtl-2.2.2
    network-3.1.4.0-TqaTt7QDPb46Ee5sVM3ZA
    network-uri-2.6.4.2-6JHGslrp0HfJBcqTpqrtq5
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    random-1.2.1.2-KvuM1oiX8xJ7hOrYY9vw8O
    readable-0.3.1-ELy7rHtD1IYJJNZUAgGrUz
    regex-posix-0.96.0.2-8pIE4uwaIUFKW3462Mf8Jo text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-E6aYj1Nnyf1Hx206wlwDyN
    unix-compat-0.7.3-KuiLNqmc5d7J4F7lggIpyW
    unordered-containers-0.2.20-3olzmtJszxXc2LJr1lW5F
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
